using Microsoft.EntityFrameworkCore;
using System;
using System.Runtime.Serialization;

namespace ScrumTaskboard
{
    public class TaskContext : DbContext 
    {
        public DbSet<ScrumTask> Tasks { get; set; }
        public DbSet<ScrumUserstory> Userstories { get; set; }
        public DbSet<ScrumCategory> Categories { get; set; }
        public DbSet<ScrumSprint> Sprints { get; set; }
        public DbSet<ScrumStatus> Status { get; set; }
        public DbSet<ScrumProject> Projects { get; set; }
        public DbSet<ScrumUser> Users { get; set; }

        public TaskContext() { }
        
        public TaskContext(DbContextOptions<TaskContext> options) : base(options) { }
    }

    public class ScrumTask
    {
        public int id { get; set; }
        public string title { get; set; }
        public string content { get; set; }
        
        public int? statusid { get; set; }
        public ScrumStatus status { get; set; }

        public int? assignedtoid { get; set; }
        public ScrumUser assignedto { get; set; }

        public int? projectid { get; set; }
        public ScrumProject project { get; set; }

        public int? userstoryid { get; set; }
        public ScrumUserstory userstory { get; set; }

        public ScrumPrio priority { get; set; }
    }

    public class ScrumUserstory
    {
        public int id { get; set; }
        public string title { get; set; }
        public string content { get; set; }
        public ScrumPrio priority { get; set; }

        public int? statusid { get; set; }
        public ScrumStatus status { get; set; }

        public int? categoryid { get; set; }
        public ScrumCategory category { get; set; }

        public int? createdbyid { get; set; }
        public ScrumUser createdby { get; set; }

        public int? projectid { get; set; }
        public ScrumProject project { get; set; }

        public int? sprintid { get; set; }
        public ScrumSprint sprint { get; set; }
    }

    public class ScrumCategory
    {
        public int id { get; set; }
        public string title { get; set; }
        public string description { get; set; }
        public string color { get; set; }

        public int? projectid { get; set; }
        public ScrumProject project { get; set; }
    }

    public class ScrumSprint
    {
        public int id { get; set; }
        public string title { get; set; }
        public string description { get; set; }
        public DateTime startDate { get; set; }
        public DateTime endDate { get; set; }


        public int? projectid { get; set; }
        public ScrumProject project { get; set; }
    }

    public class ScrumStatus
    {
        public int id { get; set; }
        public string title { get; set; }
        public string description { get; set; }
    }

    public class ScrumProject
    {
        public int id { get; set; }
        public string title { get; set; }
        public bool isprivate { get; set; }
    }

    public class ScrumUser
    {
        public int id { get; set; }
        public string name { get; set; }
    }

    public enum ScrumPrio
    {
        [EnumMember(Value = "low")]
        low,
        [EnumMember(Value = "medium")]
        medium,
        [EnumMember(Value = "high")]
        high
    }
}
